# LikeFit

LikeFit is a library to fit data for science and engineering. 
It provides a user-friendly and comprehensive interface for linear and non-linear least squares, and likelihood fits.


## Install

```sh
python -m pip install likefit
```

## Features
  * Linear and nonlinear least squares fit with a consistent interface
  * Fit of histograms with a Poisson likelihood
  * Calculation of estimators, errors, and correlations
  * Evaluation of goodness-of-fit with chi-squared test
  * Plot of error bands, confidence regions, and likelihood functions

## How to use

Check the tutorials at the end of this README for examples on how to use LikeFit.

## Contributing
If you want to contribute, please fork the repository and use a feature
branch. Pull requests are warmly welcome.

## Links
- Repository: https://github.com/ravignad/likefit/
- Tutorials: https://bit.ly/3HFlFJ1

## Licensing
The code in this project is licensed under MIT license.

